{% extends "package/edit_base.html" %}

{% block title %}Publish {{ dataset_type }} - {{ super() }}{% endblock %}

{% block secondary_content %}

    {{ super() }}

    <section class="module module-narrow module-shallow">
        <h2 class="module-heading"><i class="icon-info-sign fa fa-info-circle"></i>{% trans %}Publish Dataset in the TRUSTS Dataspace{% endtrans %}</h2>
        <div class="module-content">
            <p>
                A resource is published on the TRUSTS broker only after having at least one contract offer. Please use the form to create one.
            </p>
        </div>
    </section>

{% endblock %}


{% block primary_content_inner %}
    {% snippet "package/snippets/storepublisher_publish_form.html", data=g.pkg_dict, errors=g.errors, offering=g.offering, usage_control_policies=g.usage_policies %}
{% endblock %}
