{# Adds 'Add Dataset' button #}

{% set dataset_type = dataset_type if dataset_type else 'dataset' %}

{% link_for _('Add ' + dataset_type.title()), named_route='%s.new' % dataset_type, class_='btn btn-primary', icon='plus-square' %}
