{% import 'macros/form.html' as form %}

{% call form.input(
    field.field_name,
    id='field-' + field.field_name,
    type='number',
    label=h.scheming_language_text(field.label),
    placeholder=h.scheming_language_text(field.form_placeholder),
    value=data[field.field_name],
    error=errors[field.field_name],
    classes=field.classes if 'classes' in field else ['control-medium'],
    attrs=dict({"class": "form-control"}, **(field.get('form_attrs', {}))),
    is_required=h.scheming_field_required(field)
    )
        %}
    {%- snippet 'scheming/form_snippets/help_text.html', field=field -%}
{% endcall %}